# -*- coding: utf-8 -*-
"""
SCRIPT FOR FIGURE 6 OF GRÜNDEMANN ET AL., 2023, JOURNAL OF HYDROLOGY, DOI=10.1016/j.jhydrol.2023.129558

GPEX DATASET DOI = 10.4121/12764429

@author: ggrundemann
"""
#%% load packages
import xarray as xr
import string
import matplotlib.pyplot as plt
import matplotlib.cm as cm

#%% open GPEX dataset
datapath = '' # PATH TO GPEX DATASET

ds = xr.open_dataset(datapath + 'GPEX.nc')
mask = ds.mask.values

#%%
# parameters 
evds   = ['gev_estimate', 'pot_estimate', 'mev_estimate']
titles = ['GEV', 'POT', 'MEV']
idur   = 24
lvls   = [-1, -0.75, -0.5, -0.25, 0, 0.25, 0.5, 0.75, 1]
trs    = [2,  20,   200]
trs    = [5,  50,   500]
trs    = [10, 100, 1000]
trs    = [1,  10,   100]
#%% main manuscript - daily duration
locsy  = [0.98, 0.67, 0.36]   # for daily durations - no suptitle
fig, axes = plt.subplots(nrows=3, ncols=1, constrained_layout=True, 
                         figsize=(15/2.54,22/2.54))
for n, ax in enumerate(axes):
    evd    = evds[n]
    title = titles[n]
    immask = ax.imshow(mask, cmap=cm.gray_r, vmax=2)
    T10   = ds[evd].sel(tr=trs[0], dur=idur)
    T100  = ds[evd].sel(tr=trs[1], dur=idur)
    T1000 = ds[evd].sel(tr=trs[2], dur=idur)

    b  = T100  - T10
    b2 = b + b
    a  = T1000 - T10 - b2
    h  = a / b
    var = h.values

    imvar  = ax.imshow(var, cmap=cm.RdBu, vmin=lvls[0],vmax=lvls[-1])#,vmin=0)
    ax.set_xticks(ticks=[])
    ax.set_yticks(ticks=[])
    ax.set_title(titles[n],fontsize=8)
    plt.gcf().text(0.01, locsy[n], string.ascii_lowercase[n]+')',fontsize=8)
cbar = fig.colorbar(imvar, ticks=lvls, ax=ax, orientation='horizontal',
                    extend='both', aspect=70)

cbar.set_label('$h_\mathrm{T'+str(trs[0])+'-T'+str(trs[1])+'-T'+str(trs[2])+'}$ (-)',fontsize=8)
cbar.ax.set_xticklabels(lvls, fontsize=8)

plt.savefig('Fig_heaviness_maps.pdf', dpi=300)
